# -*- coding: utf-8 -*-
# The turbomoleio package, a python interface to Turbomole
# for preparing inputs, parsing outputs and other related tools.
#
# Copyright (C) 2018-2021 BASF SE, Matgenix SRL.
#
# This file is part of turbomoleio.
#
# Turbomoleio is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Turbomoleio is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with turbomoleio (see ~turbomoleio/COPYING). If not,
# see <https://www.gnu.org/licenses/>.

__title__ = "turbomoleio"
__description__ = "package for turbomole i/o"
__long_description__ = """Turbomoleio is a python package 
containing a set of tools for the generation of inputs and parsing of
outputs for `TURBOMOLE <http://www.turbomole.com/>`_, based on the 
open-source `pymatgen <http://pymatgen.org/>`_ library. 
Turbomoleio is compatible with python version 3.6. Full documentation 
can be found on `<https://matgenix.github.io/turbomoleio/index.html>`_. """
__version__ = "1.2.0"
